FlutterPoiosdk class

Constructors

FlutterPoiosdk()

Properties

hashCode int
The hash code for this object.
no setterinherited
platform MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterPoiosdk
final

Static Methods

initSDK({required String appkey, required String appSecret, required String serverUrl, required String statUrl, required String maxAppKey, bool debug = false, bool log = false, String? iosAppId, String? umkAppid, String? afDevKey, String? videoUnitId, String? insUnitId, String? openUnitId, String? admobOpenUnitId, String? bannerUnitId, String? nativeUnitId, String? smallNativeUnitId}) Future<bool>
初始化sdk
invokeMethodCallback(String name, Map<String, dynamic> args, Function callback) Future<void>
logEvent(String name, Map<String, String> args) Future<void>
打点
showInsAd(Function callback) Future<void>
展示插屏广告
showOpenAd(Function callback) Future<void>
展示开屏广告
showRewardVideo(Function callback) Future<void>
展示激励广告

Constants

BannerAD → const Type